@@ -42,7 +42,7 @@ def do_complete(strategy, login, user=None, redirect_name='next',
     partial = partial_pipeline_data(strategy, user, *args, **kwargs)
     if partial is not None:
         idx, backend, xargs, xkwargs = partial
-        if backend == strategy.backend_name:
+        if backend == strategy.backend.name:
             user = strategy.continue_pipeline(pipeline_index=idx,
                                               *xargs, **xkwargs)
         else:
@@ -90,7 +90,8 @@ def do_complete(strategy, login, user=None, redirect_name='next',
         url += ('?' in url and '&' or '?') + \
                '{0}={1}'.format(redirect_name, redirect_value)
     if strategy.setting('SANITIZE_REDIRECTS', True):
-        url = sanitize_redirect(strategy.request_host(), url)
+        url = sanitize_redirect(strategy.request_host(), url) or \
+              strategy.setting('LOGIN_REDIRECT_URL')
     return strategy.redirect(url)
 
 
@@ -100,7 +101,7 @@ def do_disconnect(strategy, user, association_id=None, redirect_name='next',
     out = None
     if partial is not None:
         idx, backend, xargs, xkwargs = partial
-        if backend == strategy.backend_name:
+        if backend == strategy.backend.name:
             out = strategy.disconnect(pipeline_index=idx, user=user,
                                       association_id=association_id,
                                       *args, **kwargs)
