@@ -4,6 +4,7 @@ from django.db.models import Model
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth import authenticate
 from django.template import TemplateDoesNotExist, RequestContext, loader
+from django.utils.datastructures import MergeDict
 from django.utils.translation import get_language
 
 from social.strategies.base import BaseStrategy, BaseTemplateStrategy
@@ -104,6 +105,8 @@ class DjangoStrategy(BaseStrategy):
                 'pk': val.pk,
                 'ctype': ContentType.objects.get_for_model(val).pk
             }
+        if isinstance(val, MergeDict):
+            val = dict(val)
         return val
 
     def from_session_value(self, val):
